@@ -24,7 +24,9 @@ def spark_initializer(app_name, args, additional_config=[]):
             ('javax.jdo.option.ConnectionPassword', args["hivePassword-input-dataset"]),
             ('hive.server2.enable.doAs', True),
             ('hive.metastore.client.connect.retry.delay', 5),
-            ('hive.metastore.client.socket.timeout', 1800)
+            ('hive.metastore.client.socket.timeout', 1800),
+            ('spark.sql.execution.arrow.enabled', True)  # To verify
+
         ] + additional_config
 
         config = SparkConf().setAll(config_tuples)
@@ -46,7 +48,9 @@ def spark_initializer(app_name, args, additional_config=[]):
             ('javax.jdo.option.ConnectionPassword', args["hivePassword-output-dataset"]),
             ('hive.server2.enable.doAs', True),
             ('hive.metastore.client.connect.retry.delay', 5),
-            ('hive.metastore.client.socket.timeout', 1800)
+            ('hive.metastore.client.socket.timeout', 1800),
+            ('spark.sql.execution.arrow.enabled', True)  # To verify
+
         ] + additional_config
 
         config = SparkConf().setAll(config_tuples)
