@@ -32,7 +32,7 @@ if __name__ == '__main__':
     ds_initializer.save_dataset(df=testDf)
 
     # Load the dataset
-    data = ds_initializer.load_dataset(sc=spark, read_all=True)
+    data = ds_initializer.load_dataset(sc=spark, read_all=False)
 
     # Show dataset
     data.show(truncate=False)
